from tablate.type.type_input import HtmlOuterStylesInput, FrameStylesInput, HtmlFrameStylesInput, ColumnStylesInput, \
    TextStylesInput, HtmlColumnStylesInput, HtmlTextStylesInput, RowsStylesInput, HtmlRowsStylesInput, \
    HtmlColumnInput, BaseColumnInput, GridColumnInput, TableColumnInput, TableRowsInput, BaseStylesInput, \
    TableHeaderFrameStylesInput, TableBodyFrameStylesInput, HtmlStylesInput, HtmlTextFrameStylesInput, \
    HtmlGridStylesInput, HtmlTableStylesInput, HtmlTableHeaderStylesInput, HtmlTableBodyStylesInput